### --- Test setup ---

if(FALSE) {
  library("RUnit")
  library("chngpt")
}

test.chngptm <- function() {

RNGkind("Mersenne-Twister", "Inversion")
tolerance=1e-3
if(file.exists("D:/gDrive/3software/_checkReproducibility")) tolerance=1e-6






}
